aboutsummaryrefslogtreecommitdiffstats
path: root/pkg/apis/k8s
diff options
context:
space:
mode:
authorRitu Sood <ritu.sood@intel.com>2019-08-09 11:24:26 -0700
committerRitu Sood <Ritu.Sood@intel.com>2019-08-16 13:06:16 +0000
commita6c37bf8c9c1e9f5072bfc3e43b6ec0061ee2108 (patch)
treeed3530b053600017c5ce5d7a07a04e531c6a98fe /pkg/apis/k8s
parent8fe5ed0f2cc522d22d0ca556f48f2e5922c67d3e (diff)
Add CRD Controller for Network
Add CRD controller functionality for Network creation and deletion. Related generated code is uploaded in patch: https://gerrit.opnfv.org/gerrit/#/c/ovn4nfv-k8s-plugin/+/68324/ Change-Id: Ibd3e652edc56aa1084f684438597e1b978977bbf Signed-off-by: Ritu Sood <ritu.sood@intel.com>
Diffstat (limited to 'pkg/apis/k8s')
-rw-r--r--pkg/apis/k8s/v1alpha1/network_types.go6
1 files changed, 4 insertions, 2 deletions
diff --git a/pkg/apis/k8s/v1alpha1/network_types.go b/pkg/apis/k8s/v1alpha1/network_types.go
index a52dd58..a606dbb 100644
--- a/pkg/apis/k8s/v1alpha1/network_types.go
+++ b/pkg/apis/k8s/v1alpha1/network_types.go
@@ -42,8 +42,10 @@ type DnsSpec struct {
const (
//Created indicates the status of success
Created = "Created"
- //Indicates internal Irrecoverable Error
- InternalError = "InternalError"
+ //CreateInternalError indicates create internal irrecoverable Error
+ CreateInternalError = "CreateInternalError"
+ //DeleteInternalError indicates delete internal irrecoverable Error
+ DeleteInternalError = "DeleteInternalError"
)
// NetworkStatus defines the observed state of Network